require_relative 'csvr/parse'
require_relative 'csvr/format'
require_relative 'csvr/sqlitedb'
require_relative 'csvr/cli'

module CSVR

	module_function

	def open(file)
		return App.new(file)
	end

	class App

		include CSVR::Parse
		include Format

		attr_reader :file, :rows, :types
		attr_accessor :headers, :filters

		def initialize(file)
			@file = file
		end

		def parse
			@headers ||= CSVR::Parse.headers(@file)
			@rows = CSVR::Parse.rows(@file, @headers, @filters)
			puts "HEADERS: #{@headers}, #{@headers.class}"
			puts "ROWS: #{@rows.sample}, #{@rows.sample.class}, #{@rows.class}, #{@rows.empty?}"
			@types = CSVR::Parse.type(@headers, @rows[0]) unless @rows.empty?
		end

		def format
			@headers = Format.headers(@headers, @types) unless @types.nil?
			@rows = @rows.map{ |row| Format.row(row) }
		end

		def create(db, table)
			self.parse
			self.format
			db = Database.new(db, table, @headers, @rows)
			db.create
		end
	end
end
